@@ -76,8 +76,8 @@ livefs_squash()
 
 livefs_ext2()
 {
-  # Add 500MiB extra free space for first boot + ext3 journal
-  size=$(($(du -ks ${ROOT} | cut -f1) + (512000)))
+  # Add 1024MiB extra free space for first boot + ext3 journal + swapfile
+  size=$(($(du -ks ${ROOT} | cut -f1) + (1024000)))
   MOUNTPOINT=$(mktemp -d)
   DEV=$(losetup -f)
   echo "Building ext2 filesystem."
@@ -93,6 +93,16 @@ livefs_ext2()
   # copy chroot content to image
   cp -a ${ROOT}/* ${MOUNTPOINT}
 
+  # Create a swapfile in rootfs we can use or delete later on during first boot.
+  # doing it *during* first boot adds 3min to the bootprocess so the decision
+  # was to do it here. Luckily the file will compress to nearly zero so it does
+  # not add to the image size once we gzipped the image.
+  dd if=/dev/zero of=${MOUNTPOINT}/SWAP.swap bs=1048576 count=512
+  mkswap ${MOUNTPOINT}/SWAP.swap
+
+  # make sure we dont have the buildd name set as hostname (LP: #605972)
+  echo "localhost" >${MOUNTPOINT}/etc/hostname
+
   # clean up
   umount ${MOUNTPOINT}
   rm -rf ${MOUNTPOINT}
@@ -154,7 +164,12 @@ select_mirror () {
     case $(hostname --fqdn) in
 	bld-*.mmjgroup.com)	MIRROR=${USERMIRROR};;
 	*.mmjgroup.com)		MIRROR=http://archive.mmjgroup.com/${USERMIRROR##*/};;
-	*.0c3.net)		MIRROR=http://ftp.iinet.net.au/linux/ubuntu;;
+	*.0c3.net)
+		case $ARCH in
+			i386|amd64)	MIRROR=http://mirrors.0c3.net/ubuntu/ ;;
+			*)		MIRROR=http://mirrors.0c3.net/ubuntu-ports/ ;;
+		esac
+		;;
 	*.ubuntu.com)		MIRROR=http://ftpmaster.internal/ubuntu;;
 	*.warthogs.hbd.com)	MIRROR=http://ftpmaster.internal/ubuntu;;
 	*.buildd)		MIRROR=http://ftpmaster.internal/ubuntu;;
@@ -196,9 +211,9 @@ esac; done;
 shift $((OPTIND-1))
 
 if (( $# == 0 )) || [ "X$1" = "Xall" ]; then
-    set -- ubuntu kubuntu kubuntu-mobile kubuntu-netbook edubuntu xubuntu mythbuntu gobuntu base
+    set -- ubuntu kubuntu kubuntu-mobile kubuntu-netbook edubuntu xubuntu mythbuntu gobuntu base ubuntu-headless
     if [ "$ARCH" = "i386" ]; then
-        set -- ubuntu ubuntu-dvd kubuntu kubuntu-dvd kubuntu-mobile kubuntu-netbook edubuntu edubuntu-dvd mythbuntu xubuntu gobuntu base
+        set -- ubuntu ubuntu-dvd kubuntu kubuntu-dvd kubuntu-mobile kubuntu-netbook edubuntu edubuntu-dvd mythbuntu xubuntu gobuntu base ubuntu-headless
     fi
 fi
 
@@ -210,7 +225,7 @@ fi
 
 for arg in "$@"; do
     case "$arg" in
-       ubuntu|ubuntu-dvd|ubuntu-lpia|edubuntu|edubuntu-dvd|kubuntu|kubuntu-dvd|kubuntu-mobile|kubuntu-netbook|xubuntu|mythbuntu|gobuntu|ubuntu-mid|ubuntu-netbook|ubuntu-moblin-remix|base|tocd)
+       ubuntu|ubuntu-dvd|ubuntu-lpia|edubuntu|edubuntu-dvd|kubuntu|kubuntu-dvd|kubuntu-mobile|kubuntu-netbook|xubuntu|mythbuntu|gobuntu|ubuntu-mid|ubuntu-netbook|ubuntu-moblin-remix|base|ubuntu-headless|tocd)
 	    ;;
 	*)
 	    echo bad name >&2;
@@ -239,6 +254,11 @@ for FS in "$@"; do
         mount -t tmpfs -o size=8192M tmpfs ${ROOT} && echo using tmpfs
     fi
 
+    mkdir -p ${ROOT}etc/dpkg/dpkg.cfg.d
+    cat << @@EOF > ${ROOT}etc/dpkg/dpkg.cfg.d/livecd-rootfs
+force-unsafe-io
+@@EOF
+
     mkdir -p ${ROOT}var/cache/debconf
     cat << @@EOF > ${ROOT}var/cache/debconf/config.dat
 Name: debconf/frontend
@@ -260,12 +280,12 @@ Flags: seen
 	    ;;
 	kubuntu-mobile)
 	    LIST="$LIST minimal^ standard^ kubuntu-mobile^"
-	    LIVELIST="language-support-en kubuntu-mobile-live^ laptop-detect $LIVE_BOOT_SCRIPTS"
+	    LIVELIST="kubuntu-mobile-live^ laptop-detect $LIVE_BOOT_SCRIPTS"
 	    COMP="main restricted universe"
 	    ;;
 	kubuntu-netbook)
 	    LIST="$LIST minimal^ standard^ kubuntu-netbook^"
-	    LIVELIST="language-support-en kubuntu-netbook-live^ laptop-detect $LIVE_BOOT_SCRIPTS"
+	    LIVELIST="kubuntu-netbook-live^ laptop-detect $LIVE_BOOT_SCRIPTS"
 	    ;;
 	edubuntu|edubuntu-dvd)
 	    LIST="$LIST minimal^ standard^ edubuntu-desktop-gnome^"
@@ -306,6 +326,10 @@ Flags: seen
 	    LIST="$LIST minimal^ standard^"
 	    LIVELIST="$LIVE_BOOT_SCRIPTS"
 	    ;;
+	ubuntu-headless)
+	    LIST="$LIST minimal^ standard^"
+	    LIVELIST="$LIVE_BOOT_SCRIPTS"
+	    ;;
 	tocd)
 	    LIST="$LIST minimal^ standard^"
 	    tocdtmp=`mktemp -d` || exit 1
@@ -416,6 +440,8 @@ link_in_boot = $link_in_boot
 	powerpc)	LIST="$LIST linux-powerpc linux-powerpc64-smp";;
 	sparc*)		LIST="$LIST linux-sparc64";;
 	armel)
+			#inhibit running of flash-kernel for armel
+    			export FLASH_KERNEL_SKIP=1
 			case "$SUBARCH" in
 				imx51)
 					LIST="$LIST linux-imx51"
@@ -425,11 +451,11 @@ link_in_boot = $link_in_boot
 					STRIP_VMLINUZ=no
 					;;
 				omap)
-					LIST="$LIST linux-omap"
+					LIST="$LIST linux-omap x-loader-omap3-beagle u-boot-linaro-omap3-beagle"
 					STRIP_VMLINUZ=no
 					;;
 				omap4)
-					LIST="$LIST linux-omap4"
+					LIST="$LIST linux-omap4 x-loader-omap4-panda u-boot-linaro-omap4-panda"
 					STRIP_VMLINUZ=no
 					;;
 			esac;;
@@ -680,6 +706,7 @@ Pin-Priority: 550
 	    action="mv"
 	fi
 	$action ${ROOT}/boot/vmlinu?-"${KVER}" livecd.${FSS}.kernel-"${SUBARCH}"
+	chmod 644 livecd.${FSS}.kernel-"${SUBARCH}"
 	if [ "$INITRD_COMPRESSOR" != gz ]; then
 	    zcat "livecd.${FSS}.initrd-${SUBARCH}" | "$INITRD_COMPRESSOR" -9c \
 		> "livecd.${FSS}.initrd-${SUBARCH}.new"
@@ -707,9 +734,9 @@ Pin-Priority: 550
     fi
 
     if [ "$FS" = ubuntu-netbook ] && \
-       [ "$TARGETARCH+$SUBARCH" = armel+dove ] && \
-       [ -e "$ROOT/usr/share/xsessions/une-efl.desktop" ]; then
-        chroot $ROOT /usr/lib/gdm/gdm-set-default-session une-efl
+       [ "$TARGETARCH" = armel ] && \
+       [ -e "$ROOT/usr/share/xsessions/unity-2d.desktop" ]; then
+        chroot $ROOT /usr/lib/gdm/gdm-set-default-session unity-2d
     fi
 
     # all done with the chroot; reset the debconf frontend, so Colin doesn't cry
@@ -719,6 +746,8 @@ Pin-Priority: 550
     # And now that we're done messing with debconf, destroy the backup files:
     rm -f ${ROOT}/var/cache/debconf/*-old
 
+    rm -f ${ROOT}/etc/dpkg/dpkg.cfg.d/livecd-rootfs
+
     # show the size of directories in /usr/share/doc
     checkpoint "Checking size of /usr/share/doc"
     echo BEGIN docdirs
@@ -776,7 +805,7 @@ Pin-Priority: 550
         edubuntu-dvd)
             if [ "$TARGETARCH" = "i386" ]; then
                 checkpoint "Building LTSP chroot"
-                ltsp-build-client --base $(pwd) --mirror $MIRROR --arch $TARGETARCH --dist $STE --chroot ltsp-live --purge-chroot --skipimage
+                ltsp-build-client --base $(pwd) --mirror $MIRROR --arch $TARGETARCH --dist $STE --chroot ltsp-live --late-packages ldm-edubuntu-theme,plymouth-theme-edubuntu --purge-chroot --skipimage
                 mkdir -p $(pwd)/images
                 mksquashfs $(pwd)/ltsp-live $(pwd)/images/ltsp-live.img -noF -noD -noI -no-exports -e cdrom
                 rm -Rf $(pwd)/ltsp-live
